# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global with_eclipse 1
%global with_extra 0

%global section free

%global eclipse_base            %{_libdir}/eclipse
# Note:  this next section looks weird having an arch specified in a
# noarch specfile but the parts of the build
# All arches line up between Eclipse and Linux kernel names except i386 -> x86
%ifarch %{ix86}
%global eclipse_arch    x86
%else
%global eclipse_arch   %{_arch}
%endif

Name:           icu4j
Version:        4.4.2
Release:        %mkrel 5
Epoch:          1
Summary:        International Components for Unicode for Java
License:        MIT and EPL 
URL:            http://site.icu-project.org/
Group:          Development/Java
#http://source.icu-project.org/repos/icu/icu4j/tags/release-4-4-2-eclipse37-20110208/ icu4j-4.4.2
#tar caf icu4j-4.4.2.tar.xz icu4j-4.4.2/
Source0:        icu4j-4.4.2.tar.xz
Source1:        %{name}-4.4.2.pom

## CAUTION
## Please do not forget to update this Manifest to the latest one taken from the icu4j bundle from
## out/projects/ICU4J.com.ibm.icu/com.ibm.icu-com.ibm.icu.zip
## This is needed to unbreak cyclic dependencies between Eclipse and ICU4J
Source2:        icu4j-%{version}-MANIFEST.MF

Patch0:         %{name}-crosslink.patch
BuildRequires:  ant >= 1.7.0
# FIXME:  is this necessary or is it just adding strings in the hrefs in
# the docs?
BuildRequires:  java-javadoc >= 0:1.6.0
# This is to ensure we get OpenJDK and not GCJ
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  jpackage-utils >= 0:1.5
BuildRequires:  zip
Requires:       jpackage-utils
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
# This is to ensure we get OpenJDK and not GCJ
Requires:       java >= 0:1.6.0
%if %{with_eclipse}
BuildRequires:  eclipse-pde >= 0:3.2.1
%global         debug_package %{nil}
%else
BuildArch:      noarch
%endif

%description
The International Components for Unicode (ICU) library provides robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and provides support for
supplementary characters (needed for GB 18030 repertoire support).

Java provides a very strong foundation for global programs, and IBM and the
ICU team played a key role in providing globalization technology into Sun's
Java. But because of its long release schedule, Java cannot always keep
up-to-date with evolving standards. The ICU team continues to extend Java's
Unicode and internationalization support, focusing on improving
performance, keeping current with the Unicode standard, and providing
richer APIs, while remaining as compatible as possible with the original
Java text and internationalization API design.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Java
Requires:       jpackage-utils
Requires:       java-javadoc >= 0:1.6.0

%description javadoc
Javadoc for %{name}.

%if %{with_eclipse}
%package eclipse
Summary:        Eclipse plugin for %{name}
Group:          Development/Java
Requires:       jpackage-utils

%description eclipse
Eclipse plugin support for %{name}.

%endif

%if %{with_extra}
%package extra
Summary:       Extra %{name} libraries
Group:         Development/Java
Requires:      %{name} = %{version}-%{release} 
Requires:      jpackage-utils

%description extra
Extra %{name} libraries.

%endif

%prep
%setup -q 
#%patch0 -p0

cp %{SOURCE1} .

%{__sed} -i 's/\r//' APIChangeReport.html
%{__sed} -i 's/\r//' readme.html

sed --in-place "s/ .*bootclasspath=.*//g" build.xml
sed --in-place "s/<date datetime=.*when=\"after\"\/>//" build.xml
sed --in-place "/javac1.3/d" build.xml
sed --in-place "s:/usr/lib:%{_libdir}:g" build.xml

%build
%ant -Dicu4j.javac.source=1.5 -Dicu4j.javac.target=1.5 -Dj2se.apidoc=%{_javadocdir}/java jar docs
%if %{with_eclipse}
pushd eclipse-build
  %ant -Dj2se.apidoc=%{_javadocdir}/java -Declipse.home=%{eclipse_base} \
    -Declipse.basews=gtk -Declipse.baseos=linux \
    -Declipse.basearch=%{eclipse_arch} \
    -Declipse.pde.dir=%{eclipse_base}/dropins/sdk/plugins/`ls %{eclipse_base}/dropins/sdk/plugins/|grep org.eclipse.pde.build_`
popd
%endif

%if %{with_extra}
  ant \
    -Dicu4j.javac.source=1.5 \
    -Dicu4j.javac.target=1.5 \
    -Dj2se.apidoc=%{_javadocdir}/java \
    richeditJar richeditDocs xliff cldrUtil icutzucheck jarTests jarDemos

  pushd localespi
    ant \
    -Dicu4j.javac.source=1.5 \
    -Dicu4j.javac.target=1.5 \
    build-jar
  popd
%endif
  
%install

# inject OSGi manifests
mkdir -p META-INF
cp -p %{SOURCE2} META-INF/MANIFEST.MF
touch META-INF/MANIFEST.MF
zip -u %{name}.jar META-INF/MANIFEST.MF

# jars
%__mkdir_p %{buildroot}%{_javadir}
%__cp -ap %{name}.jar %{buildroot}%{_javadir}/%{name}.jar

%if %{with_extra}
# required by apache harmony
%__cp -ap %{name}-charsets.jar %{buildroot}%{_javadir}/%{name}-charsets-%{version}.jar

%__cp -ap localespi/%{name}-localespi.jar %{buildroot}%{_javadir}/%{name}-localespi-%{version}.jar
%__cp -ap utilities.jar %{buildroot}%{_javadir}/%{name}-utilities-%{version}.jar
%__cp -ap xliff.jar %{buildroot}%{_javadir}/%{name}-xliff-%{version}.jar
%__cp -ap richedit/richedit.jar %{buildroot}%{_javadir}/%{name}-richedit-%{version}.jar
%__cp -ap icu4jtzu/icutzu.jar  %{buildroot}%{_javadir}/%{name}-icutzu-%{version}.jar
%endif
# javadoc
%__mkdir_p %{buildroot}%{_javadocdir}/%{name}-%{version}
%__cp -pr doc/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%__ln_s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%if %{with_eclipse}
# eclipse
install -d -m755 %{buildroot}/%{eclipse_base}

unzip -qq -d %{buildroot}/%{eclipse_base} eclipse-build/out/projects/ICU4J.com.ibm.icu/com.ibm.icu-com.ibm.icu.zip
%endif

# maven stuff
install -d -m 755 $RPM_BUILD_ROOT%{_mavenpomdir}
cp %{name}-4.4.2.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom
%add_to_maven_depmap com.ibm.icu %{name} %{version} JPP %{name}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root,-)
%doc readme.html APIChangeReport.html
#%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_mavendepmapfragdir}/*
%{_mavenpomdir}/*.pom

%files javadoc
%defattr(-,root,root,-)
%doc %{_javadocdir}/*

%if %{with_eclipse}
%files eclipse
%defattr(-,root,root,-)
%dir %{_libdir}/eclipse
%dir %{_libdir}/eclipse/features
%dir %{_libdir}/eclipse/plugins
%{_libdir}/eclipse/features/*
%{_libdir}/eclipse/plugins/*
%doc readme.html
%endif

%if %{with_extra}
%files extra
%defattr(0644,root,root,0755)
%{_javadir}/icu4j-charsets-%{version}.jar
%{_javadir}/icu4j-charsets.jar
%{_javadir}/icu4j-icutzu-%{version}.jar
%{_javadir}/icu4j-icutzu.jar
%{_javadir}/icu4j-localespi-%{version}.jar
%{_javadir}/icu4j-localespi.jar
%{_javadir}/icu4j-richedit-%{version}.jar
%{_javadir}/icu4j-richedit.jar
%{_javadir}/icu4j-utilities-%{version}.jar
%{_javadir}/icu4j-utilities.jar
%{_javadir}/icu4j-xliff-%{version}.jar
%{_javadir}/icu4j-xliff.jar
%endif


%changelog

* Mon Jan 09 2012 dmorgan <dmorgan> 1:4.4.2-5.mga2
+ Revision: 194263
- Add OSGi manifest for bootstrapping Eclipse

* Sun Dec 25 2011 dmorgan <dmorgan> 1:4.4.2-4.mga2
+ Revision: 187558
- Rebuild for OSGi provides.

* Sat Sep 17 2011 dmorgan <dmorgan> 1:4.4.2-3.mga2
+ Revision: 144346
- Fix file list
- Fix build w/o extra
- Disable extra for now
- Fix javadoc version requires
- Add back extra package

* Tue Jul 19 2011 dmorgan <dmorgan> 1:4.4.2-1.mga2
+ Revision: 126838
- New version 4.4.2
- Bump release to allow eclipse install

  + gil <gil>
    - add sub package extra (icu4j-charsets is required by apache harmony)
    - add sub package extra (icu4j-charsets is required by apache harmony)

* Fri Feb 11 2011 dmorgan <dmorgan> 1:4.2.1-0.2.6.mga1
+ Revision: 49988
- Fix file list
- Bump release
- Build with eclipse

* Sun Jan 16 2011 dmorgan <dmorgan> 1:4.2.1-0.2.5.mga1
+ Revision: 20284
- Update to version 4.2.1 ( sync with fedora)

* Sun Jan 16 2011 dmorgan <dmorgan> 1:3.8.1-0.2.5.mga1
+ Revision: 20267
- Fix build w/o eclipse
- imported package icu4j


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 1:3.8.1-0.2.5mdv2011.0
+ Revision: 605968
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1:3.8.1-0.2.4mdv2010.1
+ Revision: 522920
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 1:3.8.1-0.2.3mdv2010.0
+ Revision: 425328
- rebuild

  + Jérôme Soyer <saispo@mandriva.org>
    - Readd Eclipse build

* Thu Jan 29 2009 Jérôme Soyer <saispo@mandriva.org> 1:3.8.1-0.2.1mdv2009.1
+ Revision: 335225
- Build without Eclipse for downgrading it
- Add Patch
- Rewind to the previous version
- Backward to previous version for Eclipse working

* Wed Jan 21 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0:4.0.1-0.0.1mdv2009.1
+ Revision: 332064
- update to new version 4.0.1
- drop patches 2 and 3
- spec file clean

  + Alexander Kurtakov <akurtakov@mandriva.org>
    - move the eclipse bits to %%_libdir/eclipse

* Thu Jul 17 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:3.8.1-0.2.1mdv2009.0
+ Revision: 237782
- new version 3.8.1

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Nov 24 2007 David Walluck <walluck@mandriva.org> 0:3.6.1-1.6.1mdv2008.1
+ Revision: 111814
- fix BuildRequires
- sync with latest fc9

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:3.6.1-1.2.2mdv2008.0
+ Revision: 87390
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Fri Jul 27 2007 David Walluck <walluck@mandriva.org> 0:3.6.1-1.2.1mdv2008.0
+ Revision: 56202
- 3.6.1


* Tue Oct 31 2006 David Walluck <walluck@mandriva.org> 3.4.5-1mdv2007.0
+ Revision: 74076
- 3.4.5
- Import icu4j

* Mon Jul 10 2006 David Walluck <walluck@mandriva.org> 0:3.4.4-2mdv2007.0
- use JPackage spec
- license is MIT

* Sun Jul 09 2006 David Walluck <walluck@mandriva.org> 0:3.4.4-1mdv2007.0
- release

* Mon Feb 27 2006 Fernando Nasser <fnasser@redhat.com> - 0:3.2-2jpp
- First JPP 1.7 build

* Sat Jan 29 2005 David Walluck <david@jpackage.org> 0:3.2-1jpp
- release (contributed by Mary Ellen Foster <mefoster at gmail.com>)

